pub struct RiHookEvent {
pub kind: RiHookKind,
pub module: Option<String>,
pub phase: Option<RiModulePhase>,
}Expand description
Hook event structure.
This struct represents an event that is emitted when a hook is triggered. It contains information about the hook kind, the module (if applicable), and the module phase (if applicable).
Fields
kind: RiHookKindThe kind of hook that was triggered
module: Option<String>The name of the module associated with the event (if any)
phase: Option<RiModulePhase>The module phase associated with the event (if any)
Implementations
Sourceimpl RiHookEvent
impl RiHookEvent
Sourcepub fn new(
kind: RiHookKind,
module: Option<String>,
phase: Option<RiModulePhase>,
) -> Self
pub fn new( kind: RiHookKind, module: Option<String>, phase: Option<RiModulePhase>, ) -> Self
Creates a new hook event.
Sourcepub fn config_reload(_path: String, _timestamp: DateTime<Utc>) -> Self
pub fn config_reload(_path: String, _timestamp: DateTime<Utc>) -> Self
Creates a config reload event.